# lion-service

[![Python Version](https://img.shields.io/badge/python-3.9%2B-blue)](https://www.python.org/downloads/)
![PyPI - Downloads](https://img.shields.io/pypi/dm/lion-service?color=blue)
![Discord](https://img.shields.io/discord/1167495547670777866?color=7289da&label=discord&logo=discord)


API services for lion framework
